@@ -288,27 +288,32 @@ basepath = os.path.expanduser('~/share/bby/')
     };
 
     const path = `/learn/admin/lessons/${lessonId}/jupyter`;
-    $.ajax({
-      url: `https://${domain}/api/v1${path}`,
-      type: 'PUT',
-      dataType: 'json',
-      data: JSON.stringify(body),
-      contentType: 'application/json',
-      success() {
-        alert('同步成功，请刷新波波鱼步骤页后查看，中途请不要运行代码');
+    fetch(`https://${domain}/api/v1${path}`, {
+      body: JSON.stringify(body),
+      headers: {
+        'content-type': 'application/json',
       },
-      error() {
-        alert('同步失败');
-      },
-    });
+      method: 'PUT',
+    })
+      .then((response) => {
+        if (response.ok) {
+          alert('同步成功，请刷新波波鱼步骤页后查看，中途请不要运行代码');
+        } else {
+          response.json().then((res) => {
+            const reason = res.message || res.error || '原因未知';
+            alert('同步失败, ' + reason);
+          });
+        }
+      })
+      .catch((err) => {
+        console.error(err);
+      });
   };
 
   var addButtons = function () {
     // 是系统创建的bby lesson，可以同步到波波鱼
     if (
-      /work\/lessons-(\d+)-(\w+)\.ipynb/.test(
-        Jupyter.notebook.notebook_path
-      )
+      /work\/lessons-(\d+)-(\w+)\.ipynb/.test(Jupyter.notebook.notebook_path)
     ) {
       Jupyter.toolbar.add_buttons_group([
         Jupyter.keyboard_manager.actions.register(
